import { MatLegacyDialog as MatDialog } from "@angular/material/legacy-dialog";
import { WidgetDto } from "@smallstack/axios-api-client";
import { BreakpointService, FrontendSmallstackType, RouterUtilService } from "@smallstack/common-components";
import { NotificationService } from "@smallstack/i18n-components";
import { InlineTranslation } from "@smallstack/i18n-shared";
import { RxCollectionService } from "@smallstack/rx-components";
import { FrontendTypeRegistry } from "@smallstack/type-components";
import { convertGeoPointToLatLng } from "@smallstack/utils";
import { BaseWidgetComponent, WidgetTag } from "@smallstack/widget-core";
import { BehaviorSubject, Observable } from "rxjs";
import * as i0 from "@angular/core";
export interface DataTableV3ListProperty {
    columnName: string;
    index: number;
    property: string;
    title?: string | InlineTranslation;
    sortable: boolean;
    renderer: string;
    rendererDateFormat?: string;
    rendererStorePropertyProperty?: string;
    rendererStorePropertyStore?: string;
    qrCodePrefix?: string;
    dialogButtonIcon?: string;
    dialogWidth?: string;
    dialogHeight?: string;
    dialogComponent?: WidgetDto;
    dialogUrlSyncParameter?: string;
    linkLabel?: string;
    openLinkInNewWindow?: boolean;
    valueIconPairArray?: [{
        value: string;
        icon: string;
    }];
    defaultIcon?: string;
    mappingArray?: [{
        value: string;
        mappedValue: string;
    }];
    defaultValue?: string;
    i18nPrefix?: string;
    googleMapsPreviewHeight?: number;
    googleMapsPreviewWidth?: number;
    widget?: WidgetDto;
    widgetContextType?: "property" | "full";
    currency?: string;
}
export interface DataTableV3Configuration {
    listProperties: DataTableV3ListProperty[];
    typeName: string;
    type: FrontendSmallstackType;
    showEditButton: boolean;
    showDeleteButton: boolean;
    showCreateButton: boolean;
    allowMultiDelete: boolean;
    showCheckboxes: boolean;
    tableHeight: string;
}
export declare class DataTableV3WidgetComponent extends BaseWidgetComponent<DataTableV3Configuration> {
    private matDialog;
    private notificationService;
    private routerUtilService;
    private frontendTypeRegistry;
    private breakPointService;
    private rxCollectionService;
    private collection$;
    protected tableData$: Observable<any[]>;
    protected smallstackType$: Observable<FrontendSmallstackType>;
    protected searchText$: BehaviorSubject<string>;
    protected isSearching$: BehaviorSubject<boolean>;
    protected searchResult$: Observable<any[]>;
    protected hasSearchResults$: Observable<boolean>;
    protected columns$: Observable<string[]>;
    protected isLoading$: BehaviorSubject<boolean>;
    protected isEmpty$: Observable<boolean>;
    protected isMobile$: BehaviorSubject<boolean>;
    protected selectedIds: string[];
    convertGeoPointToLatLng: typeof convertGeoPointToLatLng;
    googleMapsOverlayOpened: boolean;
    errors: string[];
    mappingArray: {
        [columnName: string]: {
            [value: string]: string;
        };
    };
    WidgetTag: typeof WidgetTag;
    constructor(matDialog: MatDialog, notificationService: NotificationService, routerUtilService: RouterUtilService, frontendTypeRegistry: FrontendTypeRegistry, breakPointService: BreakpointService, rxCollectionService: RxCollectionService);
    qrCodeDialog(value: string, prefix?: string): void;
    openDialog(lp: DataTableV3ListProperty, model: {
        id: string;
        [key: string]: unknown;
    }): Promise<void>;
    openEditor(model?: any): () => Promise<void>;
    deleteData(elem: {
        id: string;
    }): () => Promise<void>;
    deleteManyData(ids: string[]): () => Promise<void>;
    protected toggleAll(checkboxEvent: Event): Promise<void>;
    protected toggleEntry(id: string, checkboxEvent: Event): Promise<void>;
    /** callback fn for when a widget got set */
    protected setWidgetListProperty(propertyName: string, newWidget: WidgetDto): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataTableV3WidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataTableV3WidgetComponent, "ng-component", never, {}, {}, never, never, true, never>;
}
